@@ -14,9 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# $Id: dio_Mysql.tcl 1565265 2014-02-06 14:20:03Z mxmanghi $
+# $Id: dio_Mysql.tcl 1813239 2017-10-24 22:48:35Z mxmanghi $
 
-package provide dio_Mysql 0.2
+package provide dio_Mysql 0.3
 
 namespace eval DIO {
     ::itcl::class Mysql {
@@ -170,6 +170,13 @@ namespace eval DIO {
                             }
                         }
                     }
+                    NULL {
+                        if {[::string toupper $val] == "NULL"} {
+                            return $val
+                        } else {
+                            return "'[quote $val]'"
+                        }
+                    }
                     default {
                         # no special code for that type!!
                         return "'[quote $val]'"
