@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Id: form.tcl 1738868 2016-04-12 21:32:29Z mxmanghi $
+# $Id: form.tcl 1773068 2016-12-07 12:53:10Z mxmanghi $
 #
 
 package require Itcl
@@ -138,7 +138,7 @@ package provide form 1.0
     # name (and the new default value is returned).
     #
     method default_value {name {newValue ""}} {
-	if {[lempty $newValue]} {
+	if {[::rivet::lempty $newValue]} {
 	    if {![info exists DefaultValues($name)]} { return }
 	    return $DefaultValues($name)
 	}
@@ -157,7 +157,7 @@ package provide form 1.0
     method default_args {type args} {
 
         # if only one argument was specified
-        if {[lempty $args]} {
+        if {[::rivet::lempty $args]} {
             if {![info exists DefaultArgs($type)]} { return }
             return $DefaultArgs($type)
         }
@@ -175,18 +175,18 @@ package provide form 1.0
     # start - generate the <form> with all of its arguments
     #
     method start {{args ""}} {
-        if {![lempty $args]} {
+        if {![::rivet::lempty $args]} {
             # replicated in constructor
             import_data form $this arguments $args
         }
-        html "<form [argstring arguments]>"
+        ::rivet::html "<form [argstring arguments]>"
     }
 
     #
     # end - generate the </form>
     #
     method end {} {
-        html "</form>"
+        ::rivet::html "</form>"
     }
 
     #
@@ -247,7 +247,7 @@ package provide form 1.0
         }
 
         # ...and emit it
-        html $string
+        ::rivet::html $string
 
     }
 
@@ -421,7 +421,7 @@ package provide form 1.0
 
         set list [import_data radiobuttons $name data $args]
 
-        if {[lempty $data(labels)]} { 
+        if {[::rivet::lempty $data(labels)]} { 
             set data(labels) $data(values) 
         }
 
@@ -470,12 +470,12 @@ package provide form 1.0
         # if there are no separate labels defined, use the list of
         # values for the labels
         #
-        if {[lempty $labels]} { 
+        if {[::rivet::lempty $labels]} { 
             set labels $values 
         }
 
         # emit the selector
-        html "<select name=\"$name\" [argstring data]>"
+        ::rivet::html "<select name=\"$name\" [argstring data]>"
 
         # emit each label-value pair
         foreach label $labels value $values {
@@ -484,9 +484,9 @@ package provide form 1.0
             } else {
             set string "<option value=\"$value\">"
             }
-            html "$string$label</option>"
+            ::rivet::html "$string$label</option>"
         }
-        html "</select>"
+        ::rivet::html "</select>"
     }
 
     #
@@ -499,7 +499,7 @@ package provide form 1.0
             set value $data(value)
             unset data(value)
         }
-        html "<textarea name=\"$name\" [argstring data]>$value</textarea>"
+        ::rivet::html "<textarea name=\"$name\" [argstring data]>$value</textarea>"
     }
 
     #
