@@ -220,7 +220,7 @@ package provide form 2.1
     method default_args {type args} {
 
         # if only one argument was specified
-        if {[lempty $args]} {
+        if {[::rivet::lempty $args]} {
             if {![info exists DefaultArgs($type)]} { return }
             return $DefaultArgs($type)
         }
@@ -238,18 +238,18 @@ package provide form 2.1
     # start - generate the <form> with all of its arguments
     #
     method start {{args ""}} {
-        if {![lempty $args]} {
+        if {![::rivet::lempty $args]} {
             # replicated in constructor
             import_data form $this arguments $args
         }
-        html "<form [argstring arguments]>"
+        ::rivet::html "<form [argstring arguments]>"
     }
 
     #
     # end - generate the </form>
     #
     method end {} {
-        html "</form>"
+        ::rivet::html "</form>"
     }
 
     #
@@ -311,7 +311,7 @@ package provide form 2.1
         }
 
         # ...and emit it
-        html $string
+        ::rivet::html $string
 
     }
 
@@ -485,7 +485,7 @@ package provide form 2.1
 
         set list [import_data radiobuttons $name data $args]
 
-        if {[lempty $data(labels)]} { 
+        if {[::rivet::lempty $data(labels)]} { 
             set data(labels) $data(values) 
         }
 
@@ -503,7 +503,7 @@ package provide form 2.1
 
         set list [import_data checkboxes $name data $args]
 
-        if {[lempty $data(labels)]} { 
+        if {[::rivet::lempty $data(labels)]} { 
             set data(labels) $data(values) 
         }
 
@@ -557,7 +557,7 @@ package provide form 2.1
         # if there are no separate labels defined, use the list of
         # values for the labels
         #
-        if {[lempty $labels]} { 
+        if {[::rivet::lempty $labels]} { 
             set labels $values 
         }
 
@@ -587,7 +587,7 @@ package provide form 2.1
         } elseif {[default_exists $name]} {
 			set value [default_value_get $name]
 		}
-        html "<textarea name=\"$name\" [argstring data]>$value</textarea>"
+        ::rivet::html "<textarea name=\"$name\" [argstring data]>$value</textarea>"
     }
 
     #
