@@ -1,7 +1,7 @@
 #
 # Session - Itcl object for web session management for Rivet
 #
-# $Id: session-class.tcl 1496086 2013-06-24 15:16:09Z mxmanghi $
+# $Id: session-class.tcl 1773068 2016-12-07 12:53:10Z mxmanghi $
 #
 
 # Copyright 2004 The Apache Software Foundation
@@ -150,7 +150,7 @@ package require Itcl
 	# if the Apache unique ID module is installed, the environment
 	# variable UNIQUE_ID will have been set.  If not, we'll get an
 	# empty string, which won't hurt anything.
-	set uniqueID [env UNIQUE_ID]
+	set uniqueID [::rivet::env UNIQUE_ID]
 
 	set sessionIdKey "$uniqueID[clock clicks][pid]$args[clock seconds]$scrambleCode[get_entropy_bytes]"
 	debug "gen_session_id - feeding this to md5: '$sessionIdKey'"
@@ -192,7 +192,7 @@ package require Itcl
     #  object
     #
     method set_session_cookie {value} {
-	cookie set $cookieName $value \
+	::rivet::cookie set $cookieName $value \
 	    -path $cookiePath \
 	    -minutes $cookieLifetime \
 	    -secure $cookieSecure \
@@ -231,7 +231,7 @@ package require Itcl
 	# see if they have a session cookie.  if they don't,
 	# set status and return.
 	#
-	set sessionCookie [cookie get $cookieName]
+	set sessionCookie [::rivet::cookie get $cookieName]
 	if {$sessionCookie == ""} {
 	    # they did not have a cookie set, they are not logged in
 	    status "no_cookie"
@@ -247,14 +247,14 @@ package require Itcl
 	debug "id: found session cookie '$cookieName' value '$sessionCookie'"
 
 	set a(session_id) $sessionCookie
-	set a(ip_address) [env REMOTE_ADDR]
+	set a(ip_address) [::rivet::env REMOTE_ADDR]
 
 	# see if there's a record matching the session ID cookie and
 	# IP address
 	set kf [list session_id ip_address]
 	set key [$dioObject makekey a $kf]
 	if {![$dioObject fetch $key a -table $sessionTable -keyfield $kf]} {
-	    debug "id: no entry in the session table for session '$sessionCookie' and address [env REMOTE_ADDR]: [$dioObject errorinfo]"
+	    debug "id: no entry in the session table for session '$sessionCookie' and address [::rivet::env REMOTE_ADDR]: [$dioObject errorinfo]"
 	    status "no_session"
 	    return ""
 	}
@@ -346,6 +346,22 @@ package require Itcl
 	return $a(data)
     }
 
+    #
+    # stash -
+    #
+    #
+
+    method stash {packageName keyvalue_d} {
+
+        dict for {key value} $keyvalue_d {
+
+            $this store $packageName $key $value
+
+        }
+
+    }
+
+
     #
     # load - given a package names returns a dictionary storing the key - value pairs for this session
     #
@@ -353,7 +369,8 @@ package require Itcl
     method load {packageName} {
         set package_d [dict create]
         
-        $dioObject forall "select key_,data from $sessionCacheTable where package_='$packageName' and session_id='[$this id]'" a {
+        $dioObject forall \
+        "select key_,data from $sessionCacheTable where package_='$packageName' and session_id='[$this id]'" a {
             dict set package_d $a(key_) $a(data)
         }
 
@@ -383,7 +400,7 @@ package require Itcl
     #
     method delete_session {{session_id ""}} {
 
-	set ip_address [env REMOTE_ADDR]
+	set ip_address [::rivet::env REMOTE_ADDR]
 
 	if {$session_id == ""} {
 	    set session_id [id]
@@ -408,7 +425,7 @@ package require Itcl
 
 	## Create their session by storing their session information in 
 	# the session table.
-	set a(ip_address) [env REMOTE_ADDR]
+	set a(ip_address) [::rivet::env REMOTE_ADDR]
 	set a(session_start_time) now
 	set a(session_update_time) now
 
