@@ -9,7 +9,7 @@
  * 	Common API layer.
  */
 
-/* $Id: TclWeb.h 1583202 2014-03-30 21:32:12Z mxmanghi $ */
+/* $Id: TclWeb.h 1647357 2014-12-22 17:35:20Z mxmanghi $ */
 
 /* Tcl 8.4 migration. */
 #ifndef CONST84
@@ -82,6 +82,8 @@ int TclWeb_PrintError(CONST84 char *errstr, int htmlflag, TclWebRequest *req);
  */
 
 int TclWeb_HeaderSet(char *header, char *val, TclWebRequest *req);
+void        TclWeb_OutputHeaderSet(char *header, char *val, TclWebRequest *req);
+const char* TclWeb_OutputHeaderGet(char *header, TclWebRequest *req);
 
 /*
  *-----------------------------------------------------------------------------
