@@ -135,7 +135,7 @@ TclWeb_SetHeaderType(char *header, TclWebRequest *req)
     if (req->headers_set)
         return TCL_ERROR;
 
-//    req->req->content_type = (char *) apr_pstrdup(req->req->pool, header);
+//  req->req->content_type = (char *) apr_pstrdup(req->req->pool, header);
 
     ap_set_content_type(req->req,apr_pstrdup(req->req->pool, header));
     req->headers_set = 1;
@@ -149,9 +149,22 @@ TclWeb_PrintHeaders(TclWebRequest *req)
     if (req->headers_printed)
         return TCL_ERROR;
 
+    /* Let's set the charset in the headers if one was set in the configuration  */
+
+    if (!req->headers_set && (req->charset != NULL)) {
+        TclWeb_SetHeaderType(apr_pstrcat(req->req->pool,"text/html;",req->charset,NULL),req);
+    }
+
+    /* Let's set the charset in the headers if one was set in the configuration  */
+
+    if (!req->headers_set && (req->charset != NULL))
+    {
+        TclWeb_SetHeaderType(apr_pstrcat(req->req->pool,"text/html;",req->charset,NULL),req);
+    }
+
     if (req->headers_set == 0)
     {
-        TclWeb_SetHeaderType(DEFAULT_HEADER_TYPE, req);
+        TclWeb_SetHeaderType(DEFAULT_HEADER_TYPE,req);
     }
     
     /*
