@@ -1,32 +1,28 @@
 /*
- * Rivet parser.
- *
- * Contains functions for loading up Tcl scripts either in flat Tcl
- * files, or in Rivet .rvt files.
- *
+ * -- Rivet parser - Contains functions for loading up Tcl scripts either
+ *    in flat Tcl files, or in Rivet .rvt files.
  */
 
-/* Copyright 2002-2004 The Apache Software Foundation
+/*
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
 
-   Licensed under the Apache License, Version 2.0 (the "License");
-   you may not use this file except in compliance with the License.
-   You may obtain a copy of the License at
+      http://www.apache.org/licenses/LICENSE-2.0
 
-        http://www.apache.org/licenses/LICENSE-2.0
-
-   Unless required by applicable law or agreed to in writing, software
-   distributed under the License is distributed on an "AS IS" BASIS,
-   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-   See the License for the specific language governing permissions and
-   limitations under the License.
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.
 */
 
-/* $Id: rivetParser.c 1500245 2013-07-06 11:58:35Z mxmanghi $ */
-
-/* Rivet config */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+/* $Id: rivetParser.c 1733936 2016-03-07 15:01:09Z mxmanghi $ */
 
 #include <string.h>
 #include <tcl.h>
