@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# $Id: apachetest.tcl 1385194 2012-09-15 22:18:33Z mxmanghi $
+# $Id: apachetest.tcl 1759926 2016-09-08 23:12:59Z mxmanghi $
 
 # This test suite provides a means to create configuration files, and
 # start apache with user-specified options.  All it needs to run is
@@ -41,7 +41,7 @@ namespace eval apachetest {
 	variable httpd_version  $::httpd_version
     # this file should be in the same directory this script is.
     variable templatefile [file join [file dirname [info script]] \
-			       template.conf.$httpd_version\.tcl]
+			       template.conf.2.tcl]
 }
 
 # apachetest::need_modules --
@@ -121,13 +121,13 @@ proc apachetest::start { options conftext code } {
     #OpenBSD related workaround, their stock apache tries to chroot by default
     #have to  add -u to the arguments to prevent this
     catch {exec uname} uname_str
-    if {[string equal $uname_str OpenBSD] && $httpd_version == 1 } {
+    if {[string equal $uname_str OpenBSD]} {
         set server_args "-u -X -f"
     } else {
-        set server_args "-X -f"
+        set server_args [list -X -f]
     }
     # There has got to be a better way to do this, aside from waiting.
-    set serverpid [eval exec  $binname $server_args \
+    set serverpid [eval exec $binname $server_args \
 	       [file join [pwd] server.conf] $options >& apachelog.txt &] 
     apachetest::connect
     if { $debug > 0 } {
@@ -208,7 +208,7 @@ proc apachetest::getcompiledin { binname } {
 # find the httpd.conf file
 
 proc apachetest::gethttpdconf { binname } {
-    set bin [open [list | "$binname" -V] r]
+    set bin [open [list | $binname -V] r]
     set options [read $bin]
     close $bin
     regexp {SERVER_CONFIG_FILE="(.*?)"} "$options" match filename
