@@ -16,8 +16,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# $Id: runtests.tcl 1538804 2013-11-04 23:51:02Z mxmanghi $
-
+# $Id: runtests.tcl 1759926 2016-09-08 23:12:59Z mxmanghi $
 
 set auto_path [linsert $auto_path 0 [file join [file dirname [info script]] apachetest]]
 
@@ -28,23 +27,32 @@ proc runtests_usage {} {
     exit 1
 }
 
-proc get_httpd_version {httpd} {
+proc get_httpd_version {httpd {bd broken_down_version}} {
+    upvar 1 $bd broken_down_version
+
 	catch {exec $httpd -v} raw_string
-	set version  [lindex [regexp -inline {([0-9]{1,}\.[0-9]{1,}\.[0-9]{1,})} $raw_string]  1]
-	if [string match "1.3.*" $version] {
-		return 1
-	} else {
-		return 2
-	}
+
+	set version_l [regexp -inline {([0-9]{1,})\.([0-9]{1,})\.([0-9]{1,})} $raw_string]
+	if {[llength $version_l]} {
+
+        lassign $version_l m major minor patchlevel
+        set broken_down_version [list $major $minor $patchlevel]
+
+    } else {
+
+        return -code error "could not identify the Apache httpd version from '$raw_string'"
+
+    }
+    return $m
 }
 
 if { [llength $argv] < 1 } {
     runtests_usage
 } else {
-    set httpd_version [get_httpd_version  [lindex $argv 0]]
+    set httpd_version [get_httpd_version [lindex $argv 0]]
 }
 
-puts stderr "Tests will be run against apache${httpd_version}"
+puts stderr "Tests will be run against apache ${httpd_version} version"
 
 package require apachetest
 
@@ -64,52 +72,41 @@ if { [catch {
     runtests_usage
 }
 
-
-if {$httpd_version == 1} {
-	apachetest::need_modules {
-		{mod_log_config		config_log_module}
-		{mod_mime		    mime_module}
-		{mod_negotiation	negotiation_module}
-		{mod_dir		    dir_module}
-		{mod_auth		    auth_module}
-		{mod_access		    access_module}
-	}
-} else {
-	apachetest::need_modules {
-		{mod_mime           mime_module}
-		{mod_negotiation    negotiation_module}
-		{mod_dir            dir_module}
-		{mod_log_config     log_config_module}
-		{mod_authz_host     authz_host_module}
-	}
+apachetest::need_modules {
+    {mod_mime           mime_module}
+    {mod_negotiation    negotiation_module}
+    {mod_dir            dir_module}
+    {mod_log_config     log_config_module}
+    {mod_authz_core     authz_core_module}
+    {mod_authz_host     authz_host_module}
+    {mod_unixd          unixd_module}
+    {mod_mpm_prefork    mpm_prefork_module}
 }
 
 apachetest::makeconf server.conf {
-    LoadModule rivet_module [file join $CWD .. src/.libs mod_rivet[info sharedlibextension]]
-
+    LoadModule rivet_module         [file join $CWD .. src/.libs mod_rivet[info sharedlibextension]]
 # User and Group directives removed to ease dependency of test suite from the output of command 'id' (from which
 # the values for these directives were inferred (Bug #53396)
 
     <IfModule mod_mime.c>
-    TypesConfig $CWD/mime.types
-    AddLanguage en .en
-    AddLanguage it .it
-    AddLanguage es .es
-    AddType application/x-httpd-rivet .rvt
-    AddType application/x-rivet-tcl .tcl
+        TypesConfig $CWD/mime.types
+        AddLanguage en .en
+        AddLanguage it .it
+        AddLanguage es .es
+        AddType application/x-httpd-rivet .rvt
+        AddType application/x-rivet-tcl   .tcl
     </IfModule>
 
-
     <IfDefine SERVERCONFTEST>
-    RivetServerConf BeforeScript 'puts "Page Header"'
-    RivetServerConf AfterScript 'puts "Page Footer"'
+        RivetServerConf BeforeScript 'puts "Page Header"'
+        RivetServerConf AfterScript 'puts "Page Footer"'
     </IfDefine>
 
     <IfDefine DIRTEST>
-    <Directory />
-    RivetDirConf BeforeScript 'puts "Page Header"'
-    RivetDirConf AfterScript 'puts "Page Footer"'
-    </Directory>
+        <Directory />
+            RivetDirConf BeforeScript 'puts "Page Header"'
+            RivetDirConf AfterScript 'puts "Page Footer"'
+        </Directory>
     </IfDefine>
 
     # We can use this to include our own stuff for each test.
@@ -118,21 +115,23 @@ apachetest::makeconf server.conf {
     # For testing, we want core dumps.
     CoreDumpDirectory $CWD
 }
+
 # Copy the rivet init files.
 file delete -force rivet
-file copy -force [file join .. rivet] .
+file copy   -force [file join .. rivet] .
 set env(TCLLIBPATH) [file normalize [file join [file dirname [info script]] rivet]]
 
 # If 'startserver' is specified on the command line, just start up the
 # server without running tests.
 
-
+puts "running test with arguments: $argv"
 switch -exact -- [lindex $argv 1] {
     startserver {
 	    apachetest::startserver
     }
     default {
         set argv [lrange $argv 1 end]
+
         source [file join . rivet.test]
     }
 }
